lidarwind.data\_operator.DataOperations
=======================================

.. currentmodule:: lidarwind.data_operator

.. autoclass:: DataOperations

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataOperations.__init__
      ~DataOperations.elevation_filter
      ~DataOperations.get_merge_data
      ~DataOperations.rename_var_90
   
   

   
   
   